==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/CELOverlayFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CELOverlayFluentImpl<A extends CELOverlayFluent<A>> extends BaseFluent<A> implements CELOverlayFluent<A>{
  public CELOverlayFluentImpl() {
  }
  public CELOverlayFluentImpl(CELOverlay instance) {
    this.withExpression(instance.getExpression()); 
    this.withKey(instance.getKey()); 
  }
  private String expression;
  private String key;
  public String getExpression() {
    return this.expression;
  }
  public A withExpression(String expression) {
    this.expression=expression; return (A) this;
  }
  public Boolean hasExpression() {
    return this.expression != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CELOverlayFluentImpl that = (CELOverlayFluentImpl) o;
    if (expression != null ? !expression.equals(that.expression) :that.expression != null) return false;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(expression,  key,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (expression != null) { sb.append("expression:"); sb.append(expression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/CELOverlayFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CELOverlayFluentImpl<A extends CELOverlayFluent<A>> extends BaseFluent<A> implements CELOverlayFluent<A>{
  public CELOverlayFluentImpl() {
  }
  public CELOverlayFluentImpl(CELOverlay instance) {
    if (instance != null) {
      this.withExpression(instance.getExpression());
      this.withKey(instance.getKey());
    }
  }
  private String expression;
  private String key;
  public String getExpression() {
    return this.expression;
  }
  public A withExpression(String expression) {
    this.expression=expression; return (A) this;
  }
  public Boolean hasExpression() {
    return this.expression != null;
  }
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public Boolean hasKey() {
    return this.key != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CELOverlayFluentImpl that = (CELOverlayFluentImpl) o;
    if (!java.util.Objects.equals(expression, that.expression)) return false;

    if (!java.util.Objects.equals(key, that.key)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(expression,  key,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (expression != null) { sb.append("expression:"); sb.append(expression + ","); }
    if (key != null) { sb.append("key:"); sb.append(key); }
    sb.append("}");
    return sb.toString();
  }
  
}
